from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.checkout_config_currency_model import CheckoutConfigCurrencyModel
from pianosdk.publisher.models.checkout_config_preview_authorization_details import CheckoutConfigPreviewAuthorizationDetails
from typing import List


class CheckoutConfigurationCheckoutFlowModel(BaseModel):
    name: Optional[str] = None
    description: Optional[str] = None
    checkout_flow_id: Optional[str] = None
    checkout_configuration_id: Optional[str] = None
    is_default: Optional[bool] = None
    auth_details: Optional['CheckoutConfigPreviewAuthorizationDetails'] = None
    available_currencies: Optional['List[CheckoutConfigCurrencyModel]'] = None


CheckoutConfigurationCheckoutFlowModel.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional
from pianosdk.publisher.models.piano_id_auth_provider_info import PianoIdAuthProviderInfo
from pianosdk.publisher.models.piano_id_user_info import PianoIdUserInfo


class CheckoutConfigPreviewAuthorizationDetails(BaseModel):
    actor_id: Optional[str] = None
    jwt: Optional[str] = None
    error_message: Optional[str] = None
    auth_provider: Optional['PianoIdAuthProviderInfo'] = None
    user: Optional['PianoIdUserInfo'] = None


CheckoutConfigPreviewAuthorizationDetails.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class CheckoutConfigCurrencyModel(BaseModel):
    code: Optional[str] = None
    name: Optional[str] = None
    symbol: Optional[str] = None


CheckoutConfigCurrencyModel.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PianoIdAuthProviderInfo(BaseModel):
    name: Optional[str] = None
    source: Optional[str] = None


PianoIdAuthProviderInfo.model_rebuild()



from datetime import date, datetime
from pydantic.main import BaseModel
from typing import Optional


class PianoIdUserInfo(BaseModel):
    aud: Optional[str] = None
    email: Optional[str] = None
    uid: Optional[str] = None
    sub: Optional[str] = None


PianoIdUserInfo.model_rebuild()
